summaryrefslogtreecommitdiff
path: root/editors/openoffice.org-1.1-devel/files/patch-jdk15
blob: f39b5414c9fa532554166944a8f47f3cbd829351 (plain) (blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
Index: jvmaccess/source/javainfoimpl.cxx
===================================================================
RCS file: /cvs/udk/jvmaccess/source/Attic/javainfoimpl.cxx,v
retrieving revision 1.7.12.6
diff -u -r1.7.12.6 javainfoimpl.cxx
--- jvmaccess/source/javainfoimpl.cxx	2 May 2005 13:30:59 -0000	1.7.12.6
+++ jvmaccess/source/javainfoimpl.cxx	10 Sep 2006 04:51:58 -0000
@@ -244,6 +244,8 @@
                         "jdk1.4.2", \
                         "diablo-jre1.3.1", \
                         "diablo-jdk1.3.1", \
+                        "diablo-jre1.5.0", \
+                        "diablo-jdk1.5.0", \
                         "linux-sun-jdk1.3.1", \
                         "linux-sun-jdk1.4.2", \
                         "linux-ibm-jdk1.3.1", \


taken from http://wiki.linuxfromscratch.org/blfs/browser/trunk/patches/OOo_1.1.5-jdk_1.5.0_fix-1.patch?rev=5150&format=txt
--- XmlSearch/src/com/sun/xmlsearch/db/VectorBtree.java	2000-11-30 12:02:54.000000000 -0600
+++ XmlSearch/src/com/sun/xmlsearch/db/VectorBtree.java	2005-04-19 01:56:30.289021048 -0500
@@ -274,10 +274,10 @@
     return accessBlock(bl.integerAt(index*4));
   }
 
-  public static void assert(boolean assertion) {
+  /*public static void assert(boolean assertion) {
     if (assertion == false)
       System.err.println("assertion failed");
-  }
+  }*/
 
   public int getIteratorBufferLength() {
     return _blockSize + _vecLen*2;

--- javaunohelper/com/sun/star/comp/helper/Bootstrap.java	2004-03-30 08:23:53.000000000 -0600
+++ javaunohelper/com/sun/star/comp/helper/Bootstrap.java	2005-04-19 01:56:30.000000000 -0500
@@ -220,11 +220,11 @@
         if (null != bootstrap_parameters)
         {
             pairs = new String [ 2 * bootstrap_parameters.size() ];
-            Enumeration enum = bootstrap_parameters.keys();
+            Enumeration enumer = bootstrap_parameters.keys();
             int n = 0;
-            while (enum.hasMoreElements())
+            while (enumer.hasMoreElements())
             {
-                String name = (String)enum.nextElement();
+                String name = (String)enumer.nextElement();
                 pairs[ n++ ] = name;
                 pairs[ n++ ] = (String)bootstrap_parameters.get( name );
             }

--- javaunohelper/com/sun/star/lib/loader/Loader.java	2004-03-30 08:25:21.000000000 -0600
+++ javaunohelper/com/sun/star/lib/loader/Loader.java	2005-04-19 01:56:30.000000000 -0500
@@ -106,9 +106,9 @@
         ClassLoader loader = clazz.getClassLoader();
         Vector res = new Vector();
         try {
-            Enumeration enum = loader.getResources( "META-INF/MANIFEST.MF" );
-            while ( enum.hasMoreElements() ) {
-                res.add( (URL) enum.nextElement() );
+            Enumeration enumer = loader.getResources( "META-INF/MANIFEST.MF" );
+            while ( enumer.hasMoreElements() ) {
+                res.add( (URL) enumer.nextElement() );
             }
             // the jarfile with the com/sun/star/lib/loader/Loader.class
             // per-entry attribute is most probably the last resource in the

--- jurt/com/sun/star/comp/typedescriptionmanager/EnumTypeDescription.java	2001-12-03 05:00:41.000000000 -0600
+++ jurt/com/sun/star/comp/typedescriptionmanager/EnumTypeDescription.java	2005-04-19 01:56:30.000000000 -0500
@@ -136,12 +136,12 @@
 				Field field = fields[nPos];
 				int nMod = field.getModifiers();
 				
-				if (Enum.class.isAssignableFrom( field.getType() ) &&
+				if (com.sun.star.uno.Enum.class.isAssignableFrom( field.getType() ) &&
 					Modifier.isPublic( nMod ) && Modifier.isFinal( nMod ) && Modifier.isStatic( nMod ))
 				{
 					try
 					{
-						values[nLen] = ((Enum)field.get( null )).getValue();
+						values[nLen] = ((com.sun.star.uno.Enum)field.get( null )).getValue();
 						names[nLen]  = field.getName();
 						++nLen;
 					}

--- jurt/com/sun/star/comp/typedescriptionmanager/TypeDescriptionManager.java	2000-09-18 10:27:52.000000000 -0500
+++ jurt/com/sun/star/comp/typedescriptionmanager/TypeDescriptionManager.java	2005-04-19 01:56:30.000000000 -0500
@@ -236,7 +236,7 @@
 								ret = new InterfaceTypeDescription( this, c );
 							else if (c.isArray())
 								ret = new SequenceTypeDescription( (XTypeDescription)getByClass( c.getComponentType(), bUnsigned, bInterface ) );
-							else if (Enum.class.isAssignableFrom( c ))
+							else if (com.sun.star.uno.Enum.class.isAssignableFrom( c ))
 								ret = new EnumTypeDescription( c );
 //  							else if (com.sun.star.uno.Union.class.isAssignableFrom( c ))
 //  								ret = new UnionTypeDescription( c );

--- jurt/com/sun/star/lib/uno/protocols/iiop/Marshal.java	2001-01-16 12:01:30.000000000 -0600
+++ jurt/com/sun/star/lib/uno/protocols/iiop/Marshal.java	2005-04-19 01:56:30.000000000 -0500
@@ -446,10 +446,10 @@
 		writeObject(typeDescription, object);
 	}
 
-	void writeEnum(Enum enum) throws Exception {
-		if(DEBUG) System.err.println("##### " + getClass().getName() + ".writeEnum:" + enum + " " + enum.getValue());
+	void writeEnum(Enum writeenum) throws Exception {
+		if(DEBUG) System.err.println("##### " + getClass().getName() + ".writeEnum:" + writeenum + " " + writeenum.getValue());
 
-		write_long(enum.getValue());
+		write_long(writeenum.getValue());
 	}
 
 	void writeThrowable(TypeDescription typeDescription, Throwable throwable) throws Exception {

--- jurt/com/sun/star/lib/uno/protocols/iiop/iiop.java	2001-02-02 03:01:03.000000000 -0600
+++ jurt/com/sun/star/lib/uno/protocols/iiop/iiop.java	2005-04-19 01:56:30.000000000 -0500
@@ -588,13 +588,13 @@
 		Enumeration elements = _flushList.elements();
 		while(elements.hasMoreElements()) {
 			Object objects[] = (Object[])elements.nextElement();
-			Enum enum = (Enum)objects[0];
+			Enum enumer = (Enum)objects[0];
 			Marshal marshal = (Marshal)objects[1];
 
 			int size = marshal.getSize();
 			byte bytes[] = marshal.reset();
 
-			writeMessageHeader(enum.getValue(), size, dataOutput);
+			writeMessageHeader(enumer.getValue(), size, dataOutput);
 			if(DEBUG) System.err.println("##### " + getClass().getName() + ".flush - bytes:" + size);
 
 			dataOutput.write(bytes, 0, size);

--- jurt/com/sun/star/lib/uno/protocols/urp/Marshal.java	2003-03-26 06:33:00.000000000 -0600
+++ jurt/com/sun/star/lib/uno/protocols/urp/Marshal.java	2005-04-19 01:56:30.000000000 -0500
@@ -293,10 +293,10 @@
 		writedouble(zDouble.doubleValue());
 	}
 
-	void writeEnum(Enum enum) {
-		if(DEBUG) System.err.println("##### " + getClass().getName() + ".writeEnum:" + enum + " " + enum.getValue());
+	void writeEnum(Enum writeenum) {
+		if(DEBUG) System.err.println("##### " + getClass().getName() + ".writeEnum:" + writeenum + " " + writeenum.getValue());
 
-		writeint(enum.getValue());
+		writeint(writeenum.getValue());
 	}
 
 	void writeThrowable(ITypeDescription iTypeDescription, Throwable throwable) {

--- odk/source/OOSupport/org/netbeans/modules/openoffice/wizard/OOAddInCreateIterator.java	2003-03-26 07:40:24.000000000 -0600
+++ odk/source/OOSupport/org/netbeans/modules/openoffice/wizard/OOAddInCreateIterator.java	2005-04-19 01:56:30.000000000 -0500
@@ -200,7 +200,7 @@
         index--;
     }
     
-    public org.openide.WizardDescriptor$Panel current() {
+    public org.openide.WizardDescriptor.Panel current() {
         return panels[index];
     }
     

--- odk/source/OOSupport/org/netbeans/modules/openoffice/wizard/OOIDLWizardIterator.java	2002-09-03 11:25:06.000000000 -0500
+++ odk/source/OOSupport/org/netbeans/modules/openoffice/wizard/OOIDLWizardIterator.java	2005-04-19 01:56:30.000000000 -0500
@@ -207,7 +207,7 @@
    index--;
   }
 
-  public org.openide.WizardDescriptor$Panel current()
+  public org.openide.WizardDescriptor.Panel current()
    {
      return panels[index];
    }

--- odk/source/OOSupport/org/netbeans/modules/openoffice/wizard/OOServiceCreateIterator.java	2003-03-26 07:40:24.000000000 -0600
+++ odk/source/OOSupport/org/netbeans/modules/openoffice/wizard/OOServiceCreateIterator.java	2005-04-19 01:56:30.000000000 -0500
@@ -214,7 +214,7 @@
         index--;
     }
     
-    public org.openide.WizardDescriptor$Panel current() {
+    public org.openide.WizardDescriptor.Panel current() {
         return panels[index];
     }
     

--- qadevOOo/runner/base/java_complex.java	2003-06-11 11:24:17.000000000 -0500
+++ qadevOOo/runner/base/java_complex.java	2005-04-19 01:56:30.000000000 -0500
@@ -178,9 +178,9 @@
                 java.io.InputStream in = connection.getInputStream();
                 Properties props = new Properties();
                 props.load(in);
-                Enumeration enum = props.keys();
-                while (enum.hasMoreElements()) {
-                    String key = (String)enum.nextElement();
+                Enumeration enumer = props.keys();
+                while (enumer.hasMoreElements()) {
+                    String key = (String)enumer.nextElement();
                     String value = (String)props.get(key);
                     param.put(key.trim(), value.trim());
                 }

--- qadevOOo/runner/org/openoffice/RunnerService.java	2003-03-31 11:01:51.000000000 -0600
+++ qadevOOo/runner/org/openoffice/RunnerService.java	2005-04-19 01:56:30.000000000 -0500
@@ -252,10 +252,10 @@
             // get Jar file from connection
             java.util.jar.JarFile f = con.getJarFile();
             // Enumerate over all entries
-            java.util.Enumeration enum = f.entries();
+            java.util.Enumeration enumer = f.entries();
 
-            while (enum.hasMoreElements()) {
-                String entry = enum.nextElement().toString();
+            while (enumer.hasMoreElements()) {
+                String entry = enumer.nextElement().toString();
                 if (entry.endsWith(".csv")) {
                     String module = null;
                     String object = null;

--- qadevOOo/runner/util/DBTools.java	2003-01-27 10:27:05.000000000 -0600
+++ qadevOOo/runner/util/DBTools.java	2005-04-19 01:56:30.000000000 -0500
@@ -673,12 +673,12 @@
         XEnumerationAccess dbContEA = (XEnumerationAccess)
             UnoRuntime.queryInterface(XEnumerationAccess.class, dbContext) ;
 
-        XEnumeration enum = dbContEA.createEnumeration() ;
+        XEnumeration enumer = dbContEA.createEnumeration() ;
 
         out.println("DatabaseContext registered DataSource's :") ;
-        while (enum.hasMoreElements()) {
+        while (enumer.hasMoreElements()) {
             try {
-                DataSourceInfo inf = new DataSourceInfo(enum.nextElement()) ;
+                DataSourceInfo inf = new DataSourceInfo(enumer.nextElement()) ;
                 inf.printInfo(out) ;
             } catch (com.sun.star.container.NoSuchElementException e) {}
             catch (com.sun.star.lang.WrappedTargetException e) {}
@@ -849,4 +849,4 @@
         throws java.sql.SQLException {
         statement.executeUpdate("drop table if exists " + tbl_name);
     }
-}
\ No newline at end of file
+}

--- qadevOOo/tests/java/ifc/reflection/_XTypeDescriptionEnumerationAccess.java	2003-01-27 12:11:20.000000000 -0600
+++ qadevOOo/tests/java/ifc/reflection/_XTypeDescriptionEnumerationAccess.java	2005-04-19 01:56:30.000000000 -0500
@@ -94,13 +94,13 @@
             return;
         }
         try {
-            XTypeDescriptionEnumeration enum = 
+            XTypeDescriptionEnumeration enumer = 
                         oObj.createTypeDescriptionEnumeration(sString, tClass, 
                         TypeDescriptionSearchDepth.INFINITE);
             try {
                 log.println("Got an enumeration.");
                 while (true) {
-                    XTypeDescription desc = enum.nextTypeDescription();
+                    XTypeDescription desc = enumer.nextTypeDescription();
                     i++;
                     log.println("\tdesc name: " + desc.getName()); 
                 }

--- qadevOOo/tests/java/mod/_dbaccess/SbaXGridControl.java	2003-05-27 07:37:57.000000000 -0500
+++ qadevOOo/tests/java/mod/_dbaccess/SbaXGridControl.java	2005-04-19 01:56:30.000000000 -0500
@@ -376,7 +376,7 @@
             new Object[]{ new Integer(0) }, new Object[]{ new Integer(1) }});
         tEnv.addObjRelation("Comparer", new Comparator() {
             public int compare(Object o1, Object o2) {
-                return ((Integer)o1).compareTo(o2);
+                return compare((Integer) o1, o2);
             }
             public boolean equals(Object obj) {
              return compare(this, obj) == 0;

--- qadevOOo/tests/java/mod/_servicemgr.uno/OServiceManager.java	2003-05-27 08:25:05.000000000 -0500
+++ qadevOOo/tests/java/mod/_servicemgr.uno/OServiceManager.java	2005-04-19 01:56:30.000000000 -0500
@@ -162,12 +162,12 @@
                 (XSet.class, oInterface) ;
             XSet set1 = (XSet) UnoRuntime.queryInterface
                 (XSet.class, srvMan) ;
-            XEnumeration enum = set1.createEnumeration();
-            Object srv = enum.nextElement();
+            XEnumeration enumer = set1.createEnumeration();
+            Object srv = enumer.nextElement();
 
             set.insert(srv) ;
 
-            newElement = enum.nextElement();
+            newElement = enumer.nextElement();
 
             XPropertySet xProp = (XPropertySet)UnoRuntime.queryInterface(
                                             XPropertySet.class, oInterface);

--- qadevOOo/tests/java/mod/_smgr/OServiceManager.java	2003-05-27 08:28:36.000000000 -0500
+++ qadevOOo/tests/java/mod/_smgr/OServiceManager.java	2005-04-19 01:56:30.000000000 -0500
@@ -162,12 +162,12 @@
                 (XSet.class, oInterface) ;
             XSet set1 = (XSet) UnoRuntime.queryInterface
                 (XSet.class, srvMan) ;
-            XEnumeration enum = set1.createEnumeration();
-            Object srv = enum.nextElement();
+            XEnumeration enumer = set1.createEnumeration();
+            Object srv = enumer.nextElement();
 
             set.insert(srv) ;
 
-            newElement = enum.nextElement();
+            newElement = enumer.nextElement();
 
             XPropertySet xProp = (XPropertySet)UnoRuntime.queryInterface(
                                             XPropertySet.class, oInterface);

--- sandbox/com/sun/star/lib/sandbox/ClassContextImpl.java	2002-11-21 10:49:00.000000000 -0600
+++ sandbox/com/sun/star/lib/sandbox/ClassContextImpl.java	2005-04-19 01:56:30.000000000 -0500
@@ -304,10 +304,10 @@
                         m_class_path_jars = class_path_jars;
                     }
                     
-                    java.util.Enumeration enum = m_class_path_jars.elements();
-                    while (enum.hasMoreElements())
+                    java.util.Enumeration enumer = m_class_path_jars.elements();
+                    while (enumer.hasMoreElements())
                     {
-                        ClassContext context = (ClassContext)enum.nextElement();
+                        ClassContext context = (ClassContext)enumer.nextElement();
                         try
                         {
                             xClass = context.loadClass( className );

--- sj2/stardiv/app/AppletProps.java	2000-09-18 11:54:03.000000000 -0500
+++ sj2/stardiv/app/AppletProps.java	2005-04-19 01:56:30.000000000 -0500
@@ -138,7 +138,7 @@
 		if (System.getProperty("http.proxyHost") != null) {
 			proxyHost.setText(System.getProperty("http.proxyHost"));
 			proxyPort.setText(System.getProperty("http.proxyPort"));
-			HttpClient.proxyPort = Integer.valueOf(System.getProperty("http.proxyPort")).intValue();
+			//HttpClient.proxyPort = Integer.valueOf(System.getProperty("http.proxyPort")).intValue();
 		} 
 		else {
 			proxyHost.setText("");

--- sj2/stardiv/controller/PropertyEditor.java	2000-09-18 11:54:03.000000000 -0500
+++ sj2/stardiv/controller/PropertyEditor.java	2005-04-19 01:56:30.000000000 -0500
@@ -197,10 +197,10 @@
 
 			m_DefaultList.removeAll();
 			m_List.removeAll();
-	        java.util.Enumeration enum = m_Properties.propertyNames();
-	        while (enum.hasMoreElements())
+	        java.util.Enumeration enumer = m_Properties.propertyNames();
+	        while (enumer.hasMoreElements())
 	        {
-	            String strKey = (String)enum.nextElement();
+	            String strKey = (String)enumer.nextElement();
 
 	            if (isDefaultKey(strKey))
 	            	addToList(m_DefaultList, strKey, m_Properties.getProperty(strKey));
@@ -551,19 +551,19 @@
     {
     	int nMax = 0;
 
-    	java.util.Enumeration enum = props.propertyNames();
-    	while (enum.hasMoreElements())
-    		nMax = Math.max(nMax, ((String)enum.nextElement()).length());
+    	java.util.Enumeration enumer = props.propertyNames();
+    	while (enumer.hasMoreElements())
+    		nMax = Math.max(nMax, ((String)enumer.nextElement()).length());
 
     	return nMax+2;
     }
 
     protected static boolean isDefaultKey(String strKey)
     {
-    	java.util.Enumeration enum = c_DefaultProperties.elements();
-    	while (enum.hasMoreElements())
+    	java.util.Enumeration enumer = c_DefaultProperties.elements();
+    	while (enumer.hasMoreElements())
     	{
-    		if (strKey.equals((String)enum.nextElement()))
+    		if (strKey.equals((String)enumer.nextElement()))
     			return true;
     	}
 
@@ -574,10 +574,10 @@
     {
     	java.util.Properties saveProps = new java.util.Properties();
 
-    	java.util.Enumeration enum = m_Properties.propertyNames();
-    	while (enum.hasMoreElements())
+    	java.util.Enumeration enumer = m_Properties.propertyNames();
+    	while (enumer.hasMoreElements())
     	{
-    		String strKey = (String)enum.nextElement();
+    		String strKey = (String)enumer.nextElement();
 
     		if (!isDefaultKey(strKey))
 	    		saveProps.put(strKey, m_Properties.getProperty(strKey));
@@ -623,9 +623,9 @@
 
 	    	try
 	    	{
-	    		java.util.Enumeration enum = System.getProperties().propertyNames();
-	    		while (enum.hasMoreElements())
-	    			c_DefaultProperties.addElement(enum.nextElement());
+	    		java.util.Enumeration enumer = System.getProperties().propertyNames();
+	    		while (enumer.hasMoreElements())
+	    			c_DefaultProperties.addElement(enumer.nextElement());
 	    	}
 	    	catch (Exception ignore0) {}
 	    }
@@ -656,10 +656,10 @@
     	}
     	catch (Exception ignore2) {}
 
-    	java.util.Enumeration enum = props.propertyNames();
-    	while (enum.hasMoreElements())
+    	java.util.Enumeration enumer = props.propertyNames();
+    	while (enumer.hasMoreElements())
     	{
-    		String propKey = (String)enum.nextElement();
+    		String propKey = (String)enumer.nextElement();
 
     		// if the key is not a default put the new property into the table
     		if (!isDefaultKey(propKey))

--- sj2/stardiv/controller/StreamObserver.java	2000-09-18 11:54:04.000000000 -0500
+++ sj2/stardiv/controller/StreamObserver.java	2005-04-19 01:56:30.000000000 -0500
@@ -65,8 +65,7 @@
 import java.util.Observable;
 import java.net.URL;
 import java.net.MalformedURLException;
-import sun.net.ProgressData;
-import sun.net.ProgressEntry;
+import sun.net.ProgressSource;
 
 
 /** 
@@ -79,12 +78,12 @@
 {
 	public StreamObserver()
 	{
-		ProgressData.pdata.addObserver( this );
+		progressSource.beginTracking();
 	}
 
 	public void dispose()
 	{
-		ProgressData.pdata.deleteObserver( this );
+		progressSource.finishTracking();
 	}
 
 	static long nLastTime;
@@ -95,48 +94,47 @@
 			nLastTime = System.currentTimeMillis();
 			
 			String aStatus = null;
-			ProgressEntry pEntry = (ProgressEntry)aArg;
-			switch( pEntry.what )
+			switch( progressSource.getState() )
 			{
-				case ProgressData.CONNECTED:
+				case CONNECTED:
 					{
 						try
 						{
-							URL aURL = new URL( pEntry.label );
+							URL aURL = progressSource.getURL();
 							aStatus = "Connect: Host " + aURL.getHost() + " contacted. Waiting for reply...";
 						}
-						catch( MalformedURLException e )
+						catch( Exception e )
 						{
-							aStatus = "Connect: " + pEntry.label;
+							aStatus = "Connect: " + progressSource.getURL().toString();
 						}
 					}
 				break;
 
-				case ProgressData.UPDATE:
+				case UPDATE:
 					if( System.currentTimeMillis() - nLastTime > 3000 )
 						// Only 1 update / 3s
 						return;
-					if( pEntry.need != 0 )
+					if( progressSource.getExpected() > 0 )
 					{
 						// Java kommt mit dem letzten Byte nicht r"uber
-						aStatus = "Transfered: " + pEntry.label + " - ";
-						int nPercent = (int)(((long)pEntry.read * 100) / pEntry.need);
+						aStatus = "Transfered: " + progressSource.getURL().toString() + " - ";
+						int nPercent = (int)(((long)progressSource.getProgress() * 100) / progressSource.getExpected());
 						aStatus += String.valueOf( nPercent ) + "% of ";
-						if( pEntry.need >= 1000 )
-							aStatus += String.valueOf( pEntry.need / 1000 ) + "K ";
+						if( progressSource.getExpected() >= 1000 )
+							aStatus += String.valueOf( progressSource.getExpected() / 1000 ) + "K ";
 						else
-							aStatus += String.valueOf( pEntry.need );
+							aStatus += String.valueOf( progressSource.getExpected() );
 						aStatus += "bytes.";
 					}
 					else
-						aStatus = "Transfered: " + pEntry.label;
+						aStatus = "Transfered: " + progressSource.getURL().toString();
 				break;
 
-				case ProgressData.NEW:
-					aStatus = "Try: " + pEntry.label;
+				case NEW:
+					aStatus = "Try: " + progressSource.getURL().toString();
 				break;
-				case ProgressData.DELETE:
-					aStatus = "Done: " + pEntry.label;
+				case DELETE:
+					aStatus = "Done: " + progressSource.getURL().toString();
 				break;
 			}
 			if( aStatus != null )
@@ -179,6 +177,7 @@
 			System.out.println( pStatus );
 		}
 	}
+	private ProgressSource progressSource;
 }
 
 

--- unoil/makefile.pmk	2002-06-20 11:41:33.000000000 -0500
+++ unoil/makefile.pmk	2005-04-19 01:56:30.000000000 -0500
@@ -77,7 +77,7 @@
 GENJAVAFILES	:= $(foreach,i,$(JAVAFILESLIST) $(GENJAVADIR)$/$(PACKAGE)$/$i)
 GENCLASSFILES	:= $(foreach,i,$(JAVAFILESLIST:b) $(GENCLASSDIR)$/$(PACKAGE)$/$i.class)
 
-JAVAFLAGS		= -target 1.1
+#JAVAFLAGS		= -target 1.1
 # --- Targets ------------------------------------------------------
 
 JAVAFILES=$(GENJAVAFILES)

--- xmerge/java/org/openoffice/xmerge/ConvertData.java	2002-03-07 10:45:20.000000000 -0600
+++ xmerge/java/org/openoffice/xmerge/ConvertData.java	2005-04-19 01:56:30.000000000 -0500
@@ -127,8 +127,8 @@
      *           <code>Vector</code> of <code>Document</code> objects.
      */
     public Enumeration getDocumentEnumeration() {
-        Enumeration enum = v.elements();
-		return (enum);
+        Enumeration enumer = v.elements();
+		return (enumer);
 	}
 
 

--- xmerge/java/org/openoffice/xmerge/converter/xml/xslt/DocumentDeserializerImpl.java	2003-05-29 04:03:38.000000000 -0500
+++ xmerge/java/org/openoffice/xmerge/converter/xml/xslt/DocumentDeserializerImpl.java	2005-04-19 01:56:30.000000000 -0500
@@ -155,14 +155,14 @@
      */
     public Document deserialize() throws ConvertException, IOException {
 	log("\nFound the XSLT deserializer");
-	Enumeration enum = cd.getDocumentEnumeration();
+	Enumeration enumer = cd.getDocumentEnumeration();
 	org.w3c.dom.Document domDoc=null;
 	DOMDocument docOut=null;
 	GenericOfficeDocument doc = null;
 	ByteArrayOutputStream baos =null;
 	GenericOfficeDocument sxwDoc = new GenericOfficeDocument("output");
-	while (enum.hasMoreElements()) {       
-		 docOut = (DOMDocument) enum.nextElement();
+	while (enumer.hasMoreElements()) {       
+		 docOut = (DOMDocument) enumer.nextElement();
 	}
 	domDoc = docOut.getContentDOM();	
 	try{

--- xmerge/java/org/openoffice/xmerge/converter/xml/xslt/PluginFactoryImpl.java	2002-04-09 07:18:44.000000000 -0500
+++ xmerge/java/org/openoffice/xmerge/converter/xml/xslt/PluginFactoryImpl.java	2005-04-19 01:56:30.000000000 -0500
@@ -183,9 +183,9 @@
 	String ext= ".txt";
 	String mimeType = null;
 	ConverterInfo ci = this.getConverterInfo();
-	Enumeration enum = ci.getDeviceMime();
-	while (enum.hasMoreElements()) {       
-	    mimeType= (String) enum.nextElement();
+	Enumeration enumer = ci.getDeviceMime();
+	while (enumer.hasMoreElements()) {       
+	    mimeType= (String) enumer.nextElement();
 	}
 	try {
 	    props.load(is);

--- xmlhelp/source/com/sun/star/help/HelpIndexer.java	2004-10-28 06:52:44.000000000 -0500
+++ xmlhelp/source/com/sun/star/help/HelpIndexer.java	2005-04-19 01:56:30.000000000 -0500
@@ -197,13 +197,13 @@
    			table.close( 0 );
 
 			System.out.println( "Indexing..." );
-      		Enumeration enum = _hashDocInfo.elements();
+      		Enumeration enumer = _hashDocInfo.elements();
         	int cut = 0;
-         	while( enum.hasMoreElements() && cut < 100000000 )
+         	while( enumer.hasMoreElements() && cut < 100000000 )
          	{
           		try
             	{
-          			DocInfo info = ( DocInfo ) enum.nextElement();
+          			DocInfo info = ( DocInfo ) enumer.nextElement();
          			String url = info.getURL();
 					if( url == null )
      				{
@@ -421,12 +421,12 @@
 
      	void dump()
       	{
-			Enumeration enum = _hash.keys();
+			Enumeration enumer = _hash.keys();
    			int j = 0;
 			String[] list = new String[ _hash.size() ];
-   			while( enum.hasMoreElements() )
+   			while( enumer.hasMoreElements() )
       		{
-      			list[j++] = ( String ) enum.nextElement();
+      			list[j++] = ( String ) enumer.nextElement();
            	}
 
 			Db table;
@@ -462,12 +462,12 @@
 
      void dumpHelptext()
      {
-		Enumeration enum = _hashHelptext.keys();
+		Enumeration enumer = _hashHelptext.keys();
    		int j = 0;
 		String[] list = new String[ _hashHelptext.size() ];
-   		while( enum.hasMoreElements() )
+   		while( enumer.hasMoreElements() )
       	{
-      		list[j++] = ( String ) enum.nextElement();
+      		list[j++] = ( String ) enumer.nextElement();
         }
 
 		Db table;

--- xmlhelp/source/com/sun/star/help/HelpTransformer.java	2001-02-07 03:35:47.000000000 -0600
+++ xmlhelp/source/com/sun/star/help/HelpTransformer.java	2005-04-19 01:56:30.000000000 -0500
@@ -14,11 +14,11 @@
 	{
 		String styleName;
 		Hashtable styles;
-		Enumeration enum = defs.getTable().keys();
+		Enumeration enumer = defs.getTable().keys();
 		
-		while( enum.hasMoreElements() )
+		while( enumer.hasMoreElements() )
 		{
-			styleName = ( String ) enum.nextElement();
+			styleName = ( String ) enumer.nextElement();
 			styles = defs.getEffectiveStyle( styleName );
 			
 			Enumeration styleOptions = styles.keys();
@@ -112,11 +112,11 @@
 		while( it.hasNext() )
 		{
 			Hashtable curr;
-			Enumeration enum = (curr = ( Hashtable )it.next()).keys();
-			while( enum.hasMoreElements() )
+			Enumeration enumer = (curr = ( Hashtable )it.next()).keys();
+			while( enumer.hasMoreElements() )
 			{
 				String str;
-				if( result.get( str = ( String ) enum.nextElement() ) == null )
+				if( result.get( str = ( String ) enumer.nextElement() ) == null )
 					result.put( str,curr.get( str ) );
 			}
 		}
@@ -129,11 +129,11 @@
 	{
 		String str;
 		Hashtable a = getEffectiveStyle( "p.def1" );
-		Enumeration enum = a.keys();
+		Enumeration enumer = a.keys();
 		
-		while( enum.hasMoreElements() )
+		while( enumer.hasMoreElements() )
 		{
-			System.out.println( (str = ( String ) enum.nextElement()) + " : " + ((String)a.get(str)) );
+			System.out.println( (str = ( String ) enumer.nextElement()) + " : " + ((String)a.get(str)) );
 		}
 	}
 	
Index: config_office/set_soenv.in
===================================================================
RCS file: /cvs/tools/config_office/set_soenv.in,v
retrieving revision 1.10.6.12
diff -u -r1.10.6.12 set_soenv.in
--- config_office/set_soenv.in	29 Apr 2005 14:58:58 -0000	1.10.6.12
+++ config_office/set_soenv.in	10 Sep 2006 08:15:16 -0000
@@ -63,7 +63,7 @@
 my ( $BIG_SVX, $COM, $CPU, $CPUNAME, $CVER, $DLLSUFFIX, $GLIBC, $GUI, $GUIBASE, $GUIENV,
       $GVER, $GVERDIR, $OS, $OSVERSION, $OUTPATH, $INPATH, $PATH_SEPERATOR, $PROSWITCH, $XPVERSION, $BOTH,
       $DEMO_ENV, $DYNAMIC_CRT, $SET_EXCEPTIONS, $emergency, $use_shl_versions, $CDPATHx, $JRELIBDIR,
-      $JRETOOLKITDIR, $JRETHREADDIR, $EXCEPTIONS, $WRAPCMD );
+      $JREEXTRALIBDIR, $JRETOOLKITDIR, $JRETHREADDIR, $EXCEPTIONS, $WRAPCMD );
 #
 #-------------------------------------------
 # IIc. Declaring the environment variables.
@@ -364,6 +364,7 @@
       $JRELIBDIR      = '$JAVA_HOME'.$ds."jre".$ds."lib".$ds."i386";
       $JRETOOLKITDIR  = '$JAVA_HOME'.$ds."jre".$ds."lib".$ds."i386".$ds."client";
       $JRETHREADDIR   = '$JAVA_HOME'.$ds."jre".$ds."lib".$ds."i386".$ds."native_threads";
+      $JREEXTRALIBDIR = '$JAVA_HOME'.$ds."jre".$ds."lib".$ds."i386".$ds."xawt";
 } 
 elsif ( $platform eq "$Linux" ) 
 {
@@ -901,6 +902,7 @@
                         $ps.$JRELIBDIR.
                         $ps.$JRETOOLKITDIR.
                         $ps.$JRETHREADDIR.
+			$ps.$JREEXTRALIBDIR.
                         $ps.$par_dir.$LIB.
                         $ps_STLPORT_LIB.
                         $ps.'$SOLARVER'.$ds.'$UPD'.$ds.'$INPATH'.$LIB.
--- jurt/com/sun/star/comp/servicemanager/ServiceManager.java	2002-10-30 09:28:39.000000000 -0600
+++ jurt/com/sun/star/comp/servicemanager/ServiceManager.java	2005-04-19 01:56:30.000000000 -0500
@@ -500,10 +500,10 @@
         throws com.sun.star.uno.RuntimeException
     {
         if (eventListener != null) {
-            java.util.Enumeration enum = eventListener.elements();
+            java.util.Enumeration enumer = eventListener.elements();
             
-            while (enum.hasMoreElements()) {
-                XEventListener listener = (XEventListener) enum.nextElement();
+            while (enumer.hasMoreElements()) {
+                XEventListener listener = (XEventListener) enumer.nextElement();
                 listener.disposing(new com.sun.star.lang.EventObject(this));
             }
         }
@@ -732,16 +732,16 @@
     public XEnumeration createContentEnumeration( String serviceName )
                 throws com.sun.star.uno.RuntimeException
     {
-        XEnumeration enum = null;
+        XEnumeration xenum = null;
         
         java.util.Vector serviceList = (java.util.Vector) factoriesByServiceNames.get(serviceName);
         
         if (serviceList != null)
-            enum = new ServiceEnumerationImpl( serviceList.elements() );
+            xenum = new ServiceEnumerationImpl( serviceList.elements() );
         else 
-            enum = new ServiceEnumerationImpl();
+            xenum = new ServiceEnumerationImpl();
             
-        return enum;
+        return xenum;
 	}
 	  
 	/**
@@ -809,11 +809,11 @@
 		/**
 		 * Constructs a new instance with a given enumeration.
 		 * <p>
 		 * @param	enum	is the enumeration which should been wrapped.
 		 * @see		com.sun.star.container.XEnumeration
 		 */
-        public ServiceEnumerationImpl(java.util.Enumeration enum) {
-            enumeration = enum;
+        public ServiceEnumerationImpl(java.util.Enumeration enumer) {
+            enumeration = enumer;
         }
             
 		/**
@@ -809,11 +809,11 @@
 		 * Constructs a new instance with a given enumeration.
 		 * <p>
-		 * @param	enum	is the enumeration which should been wrapped.
+		 * @param	enumer	is the enumeration which should been wrapped.
 		 * @see		com.sun.star.container.XEnumeration
 		 */
